------------------------------------------------------------------------
--! @file fpga_base_modules_pack.vhd
--! @brief <b>fpga_base_modules components declaration</b><p>
--!     Component declarations of all modules included in this repository
--!
--! </p>
--! <p>
--! <b>Source:</b><p>
------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;


package fpga_base_modules_pack is

    -- Global Clock and Reset Generation
    component GlobalModule is
        generic(
            gCmpPwmMax          : integer   := 64000;
            gCmpPwmWidth        : integer   := 16
        );
        port(
            iExtRstRXN          : in  std_logic;                    --! Reset
            iExtClk             : in  std_logic;                    --! External Clock
            oSysRst             : out std_logic;                    --! System Reset
            oFastClk            : out std_logic;                    --! Fast Clock 100 MHz
            oSysClk             : out std_logic;                    --! System Clock 50 MHz
            oCmpPwmCnt          : out std_logic_vector(gCmpPwmWidth -1 downto 0); --! Reference PWM
            oDsSampleClk25M0    : out std_logic;                    --! Internal DeltaSigma Clock 25 MHz for sampling the Delta Sigma Data Stream
            oDsSampleClk20M0    : out std_logic;                    --! Internal DeltaSigma Clock 20 MHz for sampling the Delta Sigma Data Stream
            oDsSampleClk10M0    : out std_logic;                    --! Internal DeltaSigma Clock 10 MHz for sampling the Delta Sigma Data Stream
            oDsSampleClk5M0     : out std_logic;                    --! Internal DeltaSigma Clock 5 MHz for sampling the Delta Sigma Data Stream
            oDsClk25M0Oddr      : out std_logic_vector(1 downto 0); --! external Delta Sigma Clock Oddr 25 MHz. Connect directly to ODDR Register
            oDsClk20M0Oddr      : out std_logic_vector(1 downto 0); --! external Delta Sigma Clock Oddr 20 MHz. Connect directly to ODDR Register
            oDsClk10M0Oddr      : out std_logic_vector(1 downto 0); --! external Delta Sigma Clock Oddr 10 MHz. Connect directly to ODDR Register
            oDsClk5M0Oddr       : out std_logic_vector(1 downto 0)  --! external Delta Sigma Clock Oddr 5 MHz. Connect directly to ODDR Register
        );
    end component GlobalModule;

    -- Double Data Rate Output Register
    component  ODDR1 is
    port (
        Clk     : in    std_logic;
        Data    : in    std_logic_vector(1 downto 0);
        Q       : out   std_logic_vector(0 downto 0));
    end component ODDR1;

    -- Clock generation (PLL)
    component PLL100M0 is
        port (
            CLK     : in std_logic;     -- external clock "ExtClk"
            RESET   : in std_logic;     -- External Reset
            CLKOP   : out std_logic;    -- System Clock (50.0 MHz)
            CLKOS   : out std_logic;    -- fast internal system clock (= 100.0 MHz)
            LOCK    : out std_logic     -- PLL lock signal, used for PLL20M0 reset
        );
    end component PLL100M0;

end fpga_base_modules_pack;